﻿using System;
using System.Windows.Forms;
using Steema.TeeChart.Pocket;
using Steema.TeeChart.Styles;
using System.Drawing;
using System.Drawing.Imaging;
using System.Reflection;
using System.Collections.Generic;

namespace ChartTestApp
{
    public partial class Form1 : Form
    {
        private readonly Bitmap m_ChartBitmap;
        private Histogram m_Histogram;
        private readonly TChart m_Chart;
        private int m_Size;

        public Form1()
        {
            InitializeComponent();
            m_Size = 27;

            BackColor = Color.White;

            m_Chart = new TChart();

            // note that this size matters. the exception is not thrown when size is for example 550x430
            // however, if the xSeries[0] was set to 5 (line 41) it would crasch for 550x430 as well.
            m_Chart.Width = 750;
            m_Chart.Height = 500;

            m_Chart.Panel.Visible = false;
            m_Chart.Walls.Back.Visible = false;

            m_ChartBitmap = new Bitmap(m_Chart.Width, m_Chart.Height);
            m_Histogram = new Histogram();
            m_Chart.Series.Add(m_Histogram);

            double[] xSeries = getArray(m_Size);
            xSeries[0] = 3;
            m_Histogram.Add(xSeries, getArray(m_Size));
        }

        protected override void OnPaint(PaintEventArgs e)
        {
            using (Graphics graphics = Graphics.FromImage(m_ChartBitmap))
            {
                ConfigureGraphics(graphics);

                graphics.Clear(Color.Fuchsia);
                // this is where the exception is thrown
                m_Chart.Draw(graphics);
            }
            using (ImageAttributes attributes = new ImageAttributes())
            {
                attributes.SetColorKey(Color.Fuchsia, Color.Fuchsia);
                Rectangle bounds = new Rectangle(0, 0, m_Chart.Width, m_Chart.Height);
                e.Graphics.DrawImage(m_ChartBitmap, bounds, 0, 0, m_Chart.Width, m_Chart.Height, GraphicsUnit.Pixel, attributes);
                attributes.ClearColorKey();
            }

            base.OnPaint(e);
        }

        public static void ConfigureGraphics(Graphics graphics)
        {
            if (Environment.OSVersion.Platform != PlatformID.WinCE)
            {
                PropertyInfo propertyInfo = graphics.GetType().GetProperty("TextRenderingHint");
                if (propertyInfo != null)
                {
                    propertyInfo.SetValue(graphics, 1, null);
                }
            }
        }

        double[] getArray(int size)
        {
            double[] list = new double[size];
            for (int i = 0; i < size; ++i)
                list[i] = i;

            return list;
        }
    }
}